.. _tutorials:

Tutorials
=========

Calculate photon-ALP mixing in different environments
-----------------------------------------------------

.. toctree::
    :hidden:

    mixing_single_cell.ipynb
    mixing_ICM_Gaussian_Turbulence.ipynb
    mixing_ICM_structured.ipynb
    mixing_IGMF.ipynb
    mixing_AGN_jet_simple.ipynb
    mixing_HelicalTangled_jet.ipynb
    mixing_gmf.ipynb

These tutorials demonstrate the usage of gammaALPs for different astrophysical environments:

- `Mixing in a homogeneous magnetic field <mixing_single_cell.html>`__ | *mixing_single_cell.ipynb*
- `Mixing in Gaussian turbulence field: Perseus cluster and from NGC 1275 <mixing_ICM_Gaussian_Turbulence.html>`__ | *mixing_ICM_Gaussian_Turbulence.ipynb*
- `Mixing in structured cavity field: Perseus cluster and from NGC 1275 <mixing_ICM_structured_field.html>`__ | *mixing_ICM_structured_field.ipynb*
- `Mixing in the intergalactic magnetic field (IGMF) <mixing_IGMF.html>`__ | *mixing_IGMF.ipynb*
- `Mixing in AGN jet with simple toroidal magnetic field <mixing_AGN_jet_simple.html>`__ | *mixing_AGN_jet_simple.ipynb*
- `Mixing in AGN jet with helical and tangled magnetic field <mixing_HelicalTangled_jet.html>`__ | *mixing_HelicalTangled_jet.ipynb*
- `Mixing in the Galactic magnetic field using the Jansson & Farrar model <mixing_gmf.html>`__ | *mixing_gmf.ipynb*

Additional features for magnetic-field environments
---------------------------------------------------

.. toctree::
    :hidden:

    rotation_measure_gauss.ipynb
    accessing_GMF_components.ipynb
    photon_dispersion.ipynb

These tutorials take a closer look at some magnetic-field environments and demonstrate additional features
such as the calculation of rotation measures for magnetic fields in galaxy clusters.

- `Calculating the coherence length and rotation measure for Gaussian turbulent field <rotation_measure_gauss.html>`__ | *rotation_measure_gauss.ipynb*
- `Accessing the components of the Galactic magnetic field models <accessing_GMF_components.html>`__ | *accessing_GMF_components.ipynb*
- `Manually including energy- and distance-dependent photon-photon dispersion <photon_dispersion.html>`__ | *photon_dispersion.ipynb*
